searchData={"content_type":"text/markdown","items":[{"doc":"Provides API wrappers for Mistral API\nSee https://docs.mistral.ai/api for further info on REST endpoints","ref":"MistralClient.html","title":"MistralClient","type":"module"},{"doc":"Creates a completion for the chat message","ref":"MistralClient.html#chat/2","title":"MistralClient.chat/2","type":"function"},{"doc":"```elixir\nMistralClient.chat(\n  \"model\": \"open-mistral-7b\",\n  \"messages\": [\n    %{\n      \"role\": \"user\",\n      \"content\": \"What is the best French cheese?\"\n    }\n  ]\n)\n```","ref":"MistralClient.html#chat/2-example-request","title":"Example request - MistralClient.chat/2","type":"function"},{"doc":"```elixir\n{:ok,\n  %{\n    choices: [\n      %{\n        \"finish_reason\" => \"stop\",\n \"index\" => 0,\n \"message\" => %{\n          \"content\" => \"It's subjective to determine the 'best' French cheese as it depends on personal preferences. Here are some popular and highly regarded French cheeses in various categories:\n\n1. Soft and Bloomy Rind: Brie de Meaux or Brie de Melun, Camembert de Normandie\n2. Hard and Cooked: Comté, Gruyère\n3. Hard and Uncooked: Cheddar-like: Comté, Beaufort, Appenzeller-style: Vacherin Fribourgeois, Alpine-style: Reblochon\n4. Blue Cheese: Roquefort, Fourme d'Ambert\n5. Goat Cheese: Chavignol, Crottin de Chavignol, Sainte-Maure de Touraine\n\nHowever, I would recommend trying a variety of French cheeses to discover your favorite. It's an enjoyable and delicious experience!\",\n          \"role\" => \"assistant\"\n        }\n      }\n   ],\n   created: 1702997889,\n   id: \"cmpl-83f575cf654b4a83b99d342f644db292\",\n   model: \"open-mistral-7b\",\n   object: \"chat.completion\",\n   usage: %{\n     \"completion_tokens\" => 204,\n     \"prompt_tokens\" => 15,\n     \"total_tokens\" => 219\n   }\n }\n}\n```\n\nN.B. to use \"stream\" mode you must be set http_options as below when you want to treat the chat completion as a stream. You may also pass in the api_key in the same way, or define in the config.exs of your elixir project.","ref":"MistralClient.html#chat/2-example-response","title":"Example response - MistralClient.chat/2","type":"function"},{"doc":"```elixir\nMistralClient.chat(\n  [\n    model: \"open-mistral-7b\",\n    messages: [\n      %{role: \"user\", content: \"What is the best French cheese?\"}\n    ],\n    stream: true\n  ],\n  MistralClient.config(http_options: %{stream_to: self(), async: :once})\n)\n|> Stream.each(fn res ->\n  IO.inspect(res)\nend)\n|> Stream.run()\n```","ref":"MistralClient.html#chat/2-example-request-stream","title":"Example request (stream) - MistralClient.chat/2","type":"function"},{"doc":"```elixir\n%{\n  \"choices\" => [\n    %{\"delta\" => %{\"role\" => \"assistant\"}, \"finish_reason\" => nil, \"index\" => 0}\n  ],\n  \"id\" => \"cmpl-9d2c56da16394e009cafbbde9cb5d725\",\n  \"model\" => \"open-mistral-7b\"\n}\n%{\n  \"choices\" => [\n    %{\n      \"delta\" => %{\n        \"content\" => \"It's subjective to determine the 'best'\",\n        \"role\" => nil\n      },\n      \"finish_reason\" => nil,\n      \"index\" => 0\n    }\n  ],\n  \"created\" => 1702999980,\n  \"id\" => \"cmpl-9d2c56da16394e009cafbbde9cb5d725\",\n  \"model\" => \"open-mistral-7b\",\n  \"object\" => \"chat.completion.chunk\"\n}\n%{\n  \"choices\" => [\n    %{\n      \"delta\" => %{\n        \"content\" => \" French cheese as it largely depends on personal preferences. Here are a\",\n        \"role\" => nil\n      },\n      \"finish_reason\" => nil,\n      \"index\" => 0\n    }\n  ],\n  \"created\" => 1702999980,\n  \"id\" => \"cmpl-9d2c56da16394e009cafbbde9cb5d725\",\n  \"model\" => \"open-mistral-7b\",\n  \"object\" => \"chat.completion.chunk\"\n}\n```\n\nSee: https://docs.mistral.ai/api#operation/createChatCompletion for the complete list of parameters you can pass to the chat function","ref":"MistralClient.html#chat/2-example-response-stream","title":"Example response (stream) - MistralClient.chat/2","type":"function"},{"doc":"Generates the config settings from the given params, using the defaults defined in the application's config.exs if not passed in params.","ref":"MistralClient.html#config/1","title":"MistralClient.config/1","type":"function"},{"doc":"```elixir\nMistralClient.config(\n  api_key: \"YOUR_MISTRAL_KEY\",\n  http_options: %{\n    stream_to: self(),\n    async: :once\n  }\n)\n```","ref":"MistralClient.html#config/1-example-request","title":"Example request - MistralClient.config/1","type":"function"},{"doc":"Creates an embedding vector representing the input text.","ref":"MistralClient.html#embeddings/2","title":"MistralClient.embeddings/2","type":"function"},{"doc":"```elixir\nMistralClient.embeddings(\n  model: \"mistral-embed\",\n  input: [\n    \"Embed this sentence.\",\n    \"As well as this one.\"\n  ]\n)\n```","ref":"MistralClient.html#embeddings/2-example-request","title":"Example request - MistralClient.embeddings/2","type":"function"},{"doc":"```elixir\n{:ok,\n %{\n  data: [\n   %{\n     \"embedding\" => [-0.0165863037109375, 0.07012939453125, 0.031494140625,\n      0.013092041015625, 0.020416259765625, 0.00977325439453125,\n      0.0256195068359375, 0.0021114349365234375, -0.00867462158203125,\n      -0.00876617431640625, -0.039520263671875, 0.058441162109375,\n      -0.025390625, 0.00748443603515625, -0.0290679931640625,\n      0.040557861328125, 0.05474853515625, 0.0258636474609375,\n      0.031890869140625, 0.0230255126953125, -0.056427001953125,\n      -0.01617431640625, -0.061248779296875, 0.012115478515625,\n      -0.045745849609375, -0.0269622802734375, -0.0079498291015625,\n      -0.03778076171875, -0.040008544921875, 8.23974609375e-4,\n      0.0242767333984375, -0.02996826171875, 0.0305023193359375,\n      -0.0022830963134765625, -0.012237548828125, -0.036163330078125,\n      -0.033172607421875, -0.044891357421875, 0.01326751708984375,\n      0.0021228790283203125, 0.00978851318359375, -2.1147727966308594e-4,\n      -0.0305633544921875, -0.0230865478515625, -0.024932861328125, ...],\n     \"index\" => 0,\n     \"object\" => \"embedding\"\n   },\n   %{\n     \"embedding\" => [-0.0234222412109375, 0.039337158203125,\n      0.052398681640625, -0.0183868408203125, 0.03399658203125,\n      0.003879547119140625, 0.024688720703125, -5.402565002441406e-4,\n      -0.0119171142578125, -0.006988525390625, -0.0136260986328125,\n      0.041839599609375, -0.0274810791015625, -0.015411376953125,\n      -0.041412353515625, 0.0305328369140625, 0.006023406982421875,\n      0.001140594482421875, -0.007167816162109375, 0.01085662841796875,\n      -0.03668212890625, -0.033111572265625, -0.044586181640625,\n      0.020538330078125, -0.0423583984375, -0.03131103515625,\n      -0.0119781494140625, -0.048736572265625, -0.0850830078125,\n      0.0203857421875, -0.0023899078369140625, -0.0249176025390625,\n      0.019500732421875, 0.007068634033203125, 0.0301055908203125,\n      -0.041534423828125, -0.0255584716796875, -0.0246429443359375,\n      0.022674560546875, -2.760887145996094e-4, -0.015045166015625,\n      -0.01788330078125, 0.0146484375, -0.005573272705078125, ...],\n     \"index\" => 1,\n     \"object\" => \"embedding\"\n   }\n  ],\n  id: \"embd-7d921a4410e249b9960195ab6705b255\",\n  model: \"mistral-embed\",\n  object: \"list\",\n  usage: %{\n    \"completion_tokens\" => 0,\n    \"prompt_tokens\" => 15,\n    \"total_tokens\" => 15\n  }\n}}\n```\n\nSee: https://docs.mistral.ai/api#operation/createEmbedding","ref":"MistralClient.html#embeddings/2-example-response","title":"Example response - MistralClient.embeddings/2","type":"function"},{"doc":"Retrieve the list of available models","ref":"MistralClient.html#models/0","title":"MistralClient.models/0","type":"function"},{"doc":"```elixir\nMistralClient.models()\n```","ref":"MistralClient.html#models/0-example-request","title":"Example request - MistralClient.models/0","type":"function"},{"doc":"```elixir\n{:ok,\n  %{\n    data: [\n      %{\n        \"created\" => 1702997889,\n        \"id\" => \"mistral-medium-latest\",\n        \"object\" => \"model\",\n        \"owned_by\" => \"mistralai\",\n        \"parent\" => nil,\n        \"permission\" => [\n          %{\n            \"allow_create_engine\" => false,\n            \"allow_fine_tuning\" => false,\n            \"allow_logprobs\" => false,\n            ....\n           }\n        ],\n        \"root\" => nil\n      }\n    ]\n  }\n}\n```\n\nSee: https://docs.mistral.ai/api#operation/listModels","ref":"MistralClient.html#models/0-example-response","title":"Example response - MistralClient.models/0","type":"function"},{"doc":"","ref":"MistralClient.html#start/2","title":"MistralClient.start/2","type":"function"}]}